==> webgui_7.6.27.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Asset_Wobject.pm <==
package WebGUI::i18n::English::Asset_Wobject;
use strict;

our $I18N = {

	'title' => {
		message => q|The title for this wobject.|,
		lastUpdated => 1148750705,
	},

	'displayTitle' => {
		message => q|A conditional variable for whether or not the title should be displayed.|,
		lastUpdated => 1148750705,
	},

	'description' => {
		message => q|The description of this wobject.|,
		lastUpdated => 1148750705,
	},

	'assetId' => {
		message => q|The unique identifier that WebGUI uses to control this asset.|,
		lastUpdated => 1148750705,
	},

	'styleTemplateId' => {
		message => q|The assetId of the template for displaying the Asset.|,
		lastUpdated => 1167374549,
	},

	'printableStyleTemplateId' => {
		message => q|The assetId of the template for displaying the Asset for printing.|,
		lastUpdated => 1167374550,
	},

	'originalURL' => {
		message => q|If this wobject is a shortcut, then this URL will direct you to the original asset.|,
		lastUpdated => 1148750705,
	},

          '1079' => {
                      lastUpdated => 1073152790,
                      message => q|Printable Style|
                    },
          '827' => {
                     message => q|Wobject Template Variables|,
                     lastUpdated => 1052046436,
                   },

        '174 description' => {
                message => q|Do you wish to display the Wobject's title? On some sites, displaying the title is not necessary.|,
                lastUpdated => 1119410887,
        },

        '1073 description' => {
                message => q|Select a style template from the list to enclose your Wobject if it is viewed directly.  If the Wobject
is displayed as part of a Layout Asset, the Layout Asset's <b>Style Template</b> is used instead.|,
                lastUpdated => 1119410887,
        },

        '1079 description' => {
                message => q|This sets the printable style for this page to be something other than the WebGUI Default Printable Style.  It behaves similarly to the <b>Style Template</b> with respect to when it is used.|,
                lastUpdated => 1119410887,
        },

	'85 description' => {
                message => q|A content area in which you can place as much content as you wish. For instance, even before an FAQ there is usually a paragraph describing what is contained in the FAQ. |,
                lastUpdated => 1165364350,
        },


          '42' => {
                    lastUpdated => 1031514049,
                    message => q|Please Confirm|
                  },
          '174' => {
                     lastUpdated => 1031514049,
                     message => q|Display the title?|
                   },
          '1073' => {
                      lastUpdated => 1070027660,
                      message => q|Style Template|
                    },
          '44' => {
                    lastUpdated => 1031514049,
                    message => q|Yes, I'm sure.|
                  },
          '85' => {
                    lastUpdated => 1031514049,
                    message => q|Description|
                  },
	'45' => {
		lastUpdated => 1031514049,
		message => q|No, I made a mistake.|
	},

	'assetName' => {
		message => q|Wobject|,
		lastUpdated => 1128830333,
	},


        'add' => {
                message => q|Add|,
                lastUpdated => 1128575345,
        },

        'edit' => {
                message => q|Edit|,
                lastUpdated => 1128575345,
        },

	'wobject template variables title' => {
		message => q|Wobject Template Asset Variables|,
		lastUpdated => 1167374430,
	},

};

1;

==> webgui_7.7.30.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Asset_Wobject.pm <==
package WebGUI::i18n::English::Asset_Wobject;
use strict;

our $I18N = {

	'title' => {
		message => q|The title for this wobject.|,
		lastUpdated => 1148750705,
	},

	'displayTitle' => {
		message => q|A conditional variable for whether or not the title should be displayed.|,
		lastUpdated => 1148750705,
	},

	'description' => {
		message => q|The description of this wobject.|,
		lastUpdated => 1148750705,
	},

	'assetId' => {
		message => q|The unique identifier that WebGUI uses to control this asset.|,
		lastUpdated => 1148750705,
	},

	'styleTemplateId' => {
		message => q|The assetId of the template for displaying the Asset.|,
		lastUpdated => 1167374549,
	},

	'printableStyleTemplateId' => {
		message => q|The assetId of the template for displaying the Asset for printing.|,
		lastUpdated => 1167374550,
	},

	'originalURL' => {
		message => q|If this wobject is a shortcut, then this URL will direct you to the original asset.|,
		lastUpdated => 1148750705,
	},

          '1079' => {
                      lastUpdated => 1073152790,
                      message => q|Printable Style|
                    },
          '827' => {
                     message => q|Wobject Template Variables|,
                     lastUpdated => 1052046436,
                   },

        '174 description' => {
                message => q|Do you wish to display the Wobject's title? On some sites, displaying the title is not necessary.|,
                lastUpdated => 1119410887,
        },

        '1073 description' => {
                message => q|Select a style template from the list to enclose your Wobject if it is viewed directly.  If the Wobject
is displayed as part of a Layout Asset, the Layout Asset's <b>Style Template</b> is used instead.|,
                lastUpdated => 1119410887,
        },

        '1079 description' => {
                message => q|This sets the printable style for this page to be something other than the WebGUI Default Printable Style.  It behaves similarly to the <b>Style Template</b> with respect to when it is used.|,
                lastUpdated => 1119410887,
        },

	'85 description' => {
                message => q|A content area in which you can place as much content as you wish. For instance, even before an FAQ there is usually a paragraph describing what is contained in the FAQ. |,
                lastUpdated => 1165364350,
        },


          '42' => {
                    lastUpdated => 1031514049,
                    message => q|Please Confirm|
                  },
          '174' => {
                     lastUpdated => 1031514049,
                     message => q|Display the title?|
                   },
          '1073' => {
                      lastUpdated => 1070027660,
                      message => q|Style Template|
                    },
          '44' => {
                    lastUpdated => 1031514049,
                    message => q|Yes, I'm sure.|
                  },
          '85' => {
                    lastUpdated => 1031514049,
                    message => q|Description|
                  },
	'45' => {
		lastUpdated => 1031514049,
		message => q|No, I made a mistake.|
	},

	'assetName' => {
		message => q|Wobject|,
		lastUpdated => 1128830333,
	},


        'add' => {
                message => q|Add|,
                lastUpdated => 1128575345,
        },

        'edit' => {
                message => q|Edit|,
                lastUpdated => 1128575345,
        },

	'wobject template variables title' => {
		message => q|Wobject Template Asset Variables|,
		lastUpdated => 1167374430,
	},

    'mobileStyleTemplateId label' => {
        message => 'Mobile Style Template'
    },
    'mobileStyleTemplateId description' => {
        message => q|Select a style template from the list to enclose your asset if it is viewed on a mobile browser|,
    },

};

1;
